@@ -67,7 +67,7 @@ def read_values_from_array(query_columns_description: list, dis: DataInputStream
 
         if dtype == "LONG":
             value_array.append(dis.read_long())
-        elif type == "STRING":
+        elif dtype == "STRING":
             value_array.append(dis.read_utf().decode())
         elif dtype == "INT":
             value_array.append(dis.read_int())
