@@ -294,6 +294,7 @@ class Cursor(common.DBAPICursor):
         return self._data
 
     def _fetch_all(self):
+        _logger.info("fetching all from overriden method")
         self._data = list()
         row = self.fetchone()
         while row:
@@ -303,9 +304,11 @@ class Cursor(common.DBAPICursor):
         return self._data
 
     def fetchall(self):
+        _logger.info("fetching all")
         return self._fetch_all()
 
     def fetchone(self):
+        _logger.info("fetching one")
         client = self.connection.client
         buffer = client.getNextResultRow(self._query_id)
 
@@ -336,8 +339,6 @@ class Cursor(common.DBAPICursor):
         """
         pass
 
-    def reopen(self):
-        self.connection
 
 class Error(Exception):
     pass
