@@ -388,18 +388,3 @@ class E6xdbE6xDialect(E6xDialect):
     def __init__(self):
         super(E6xdbE6xDialect, self).__init__()
 
-
-if __name__ == '__main__':
-    dialect = E6xdbE6xDialect()
-    from urllib.parse import urlparse
-
-    args = dialect.create_connect_args(urlparse("e6xdb://admin:admin@localhost:9000/?schema=./input/tpcds_330mb"))
-    connection = dialect.dbapi.connect(args)
-    cursor = None
-    if isinstance(connection, Engine):
-        cursor = connection.raw_connection().connection.cursor()
-    elif isinstance(connection, Connection):
-        cursor = connection.connection.cursor()
-    cursor.execute("select * from date_dim")
-    data = cursor.fetchall()
-    e6x1 = dialect.dbapi()
